@@ -1,4 +1,4 @@
-from base.APIRequest import *
+from phabricator.base.APIRequest import *
 
 class QueryPaste(APIRequest):
 
@@ -9,6 +9,11 @@ class QueryPaste(APIRequest):
     def getUrl(self):
         return "paste.query"
 
+    def processResponse(self, response):
+    	for key in response.keys():
+    		print "Paste Id: %s" % key 
+
+
 if __name__ == "__main__":
     print "making a request"
     myquery = QueryPaste()
